@@ -1,12 +1,17 @@
-/* Copyright 2012 Roger P. Woods, M.D. */
-/* Modified 10/12/2012 */
+/* Copyright 2012-2014 Roger P. Woods, M.D. */
+/* Modified 6/11/2014 */
 
 /*
  * compute Y=R*X where X and Y are N X M matrices and R is a random orthonormal matrix
  *
  */
  
- #include "AIR.h"
+#include "AIR.h"
+#ifdef USING_R
+#include <R.h>
+#include <Rmath.h>
+#endif
+
 
 static void mulmat(double **a, const unsigned int m, const unsigned int n, double **b, const unsigned int r, double **c)
 {
@@ -35,6 +40,10 @@ void AIR_random_rotation(const unsigned int skip, double **r, const unsigned int
 		double pi=2.0*acos(0);
 		unsigned int randomization;
 		
+#ifdef USING_R
+		GetRNGstate();
+#endif
+		
 		for(randomization=0; randomization<=skip; randomization++){
 			AIR_Error errcode=1;
 			do{
@@ -47,7 +56,11 @@ void AIR_random_rotation(const unsigned int skip, double **r, const unsigned int
 						unsigned int j;
 						for(j=0; j<i; j++){
 						
+#ifndef USING_R
 							double angle=2*pi*rand()/(RAND_MAX+1.0);
+#else
+							double angle=2*pi*unif_rand();
+#endif
 							if(angle>pi) angle-=2*pi;
 							
 							r[i][j]=angle;
@@ -58,6 +71,9 @@ void AIR_random_rotation(const unsigned int skip, double **r, const unsigned int
 				errcode=AIR_eexper_pade(n, r, wrk, 0);
 			} while (errcode!=0);
 		}
+#ifdef USING_R
+		PutRNGstate();
+#endif
 	}
 	mulmat(r, n, n, x, m, y);
 }
